linch-pin documentation
=======================

About linch-pin
^^^^^^^^^^^^^^^
Welcome to the Ansible documentation!

Linch-pin provides a collection of Ansible playbooks for provisioning, decommissioning, and managing resources across multiple infrastructures.
The main goal of linch-pin is to facilitate provisioning and orchestration of resources in a multi-cloud environment through a topology file.

.. toctree::
   :maxdepth: 1

   intro
   config
   topologies
   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

